@@ -8,10 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Pod::Weaver::PluginBundle::RSRCHBOY;
-BEGIN {
-  $Pod::Weaver::PluginBundle::RSRCHBOY::AUTHORITY = 'cpan:RSRCHBOY';
-}
-$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.051';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.052';
 # ABSTRACT: Document your modules like RSRCHBOY does
 
 use strict;
@@ -85,7 +83,7 @@ Pod::Weaver::PluginBundle::RSRCHBOY - Document your modules like RSRCHBOY does
 
 =head1 VERSION
 
-This document describes version 0.051 of Pod::Weaver::PluginBundle::RSRCHBOY - released October 14, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.052 of Pod::Weaver::PluginBundle::RSRCHBOY - released November 12, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
