@@ -8,10 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Pod::Weaver::Section::RSRCHBOY::Authors;
-BEGIN {
-  $Pod::Weaver::Section::RSRCHBOY::Authors::AUTHORITY = 'cpan:RSRCHBOY';
-}
-$Pod::Weaver::Section::RSRCHBOY::Authors::VERSION = '0.051';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+$Pod::Weaver::Section::RSRCHBOY::Authors::VERSION = '0.052';
 # ABSTRACT: An AUTHORS section with materialistic pleasures
 
 use v5.10;
@@ -106,7 +104,7 @@ Pod::Weaver::Section::RSRCHBOY::Authors - An AUTHORS section with materialistic
 
 =head1 VERSION
 
-This document describes version 0.051 of Pod::Weaver::Section::RSRCHBOY::Authors - released October 14, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.052 of Pod::Weaver::Section::RSRCHBOY::Authors - released November 12, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 DESCRIPTION
 
