@@ -8,10 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Pod::Weaver::Section::RSRCHBOY::LazyAttributes;
-BEGIN {
-  $Pod::Weaver::Section::RSRCHBOY::LazyAttributes::AUTHORITY = 'cpan:RSRCHBOY';
-}
-$Pod::Weaver::Section::RSRCHBOY::LazyAttributes::VERSION = '0.051';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+$Pod::Weaver::Section::RSRCHBOY::LazyAttributes::VERSION = '0.052';
 # ABSTRACT: Prefaced lazy attributes section
 
 use Moose;
@@ -49,7 +47,7 @@ Pod::Weaver::Section::RSRCHBOY::LazyAttributes - Prefaced lazy attributes sectio
 
 =head1 VERSION
 
-This document describes version 0.051 of Pod::Weaver::Section::RSRCHBOY::LazyAttributes - released October 14, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.052 of Pod::Weaver::Section::RSRCHBOY::LazyAttributes - released November 12, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SEE ALSO
 
